@@ -5,6 +5,7 @@ import random
 import socket
 from uuid import UUID
 
+import async_timeout
 import orjson
 
 from .const import BASE_UUID
@@ -35,7 +36,7 @@ def iscoro(func):
     return asyncio.iscoroutinefunction(func)
 
 
-def get_local_address():
+def get_local_address() -> str:
     """
     Grabs the local IP address using a socket.
 
@@ -49,7 +50,7 @@ def get_local_address():
         addr = s.getsockname()[0]
     finally:
         s.close()
-    return addr
+    return str(addr)
 
 
 def long_to_bytes(n):
@@ -135,7 +136,8 @@ async def event_wait(event, timeout):
     :rtype: bool
     """
     try:
-        await asyncio.wait_for(event.wait(), timeout)
+        async with async_timeout.timeout(timeout):
+            await event.wait()
     except asyncio.TimeoutError:
         pass
     return event.is_set()
